<?php
// Mostrar errores durante desarrollo
ini_set('display_errors', 1);
error_reporting(E_ALL);
header('Content-Type: application/json');

include "conex.php";

// Validar que sea método POST
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'message' => 'Método no permitido.']);
    exit;
}

// Validar campo de texto
$descripcion = trim($_POST['descripcion'] ?? '');
if ($descripcion === '') {
    echo json_encode(['success' => false, 'message' => 'La descripción no puede estar vacía.']);
    exit;
}

// Validar archivo
if (!isset($_FILES['video']) || $_FILES['video']['error'] !== UPLOAD_ERR_OK) {
    echo json_encode(['success' => false, 'message' => 'Archivo no recibido o con error.']);
    exit;
}

// Validar extensión (solo mp4)
$nombreArchivo = $_FILES['video']['name'];
$extension = strtolower(pathinfo($nombreArchivo, PATHINFO_EXTENSION));
if ($extension !== 'mp4') {
    echo json_encode(['success' => false, 'message' => 'Solo se permiten archivos MP4.']);
    exit;
}

// Validar tamaño (máximo 21 MB)
$tamanoMax = 21 * 1024 * 1024; // 21 MB en bytes
if ($_FILES['video']['size'] > $tamanoMax) {
    echo json_encode(['success' => false, 'message' => 'El archivo supera los 21 MB permitidos.']);
    exit;
}

// Crear carpeta si no existe
$directorio = "videos/";
if (!file_exists($directorio)) {
    mkdir($directorio, 0755, true);
}

// Crear nombre de archivo único
$nombreSeguro = preg_replace('/[^a-zA-Z0-9_\-]/', '', pathinfo($nombreArchivo, PATHINFO_FILENAME));
$nombreFinal = $directorio . time() . "_" . $nombreSeguro . ".mp4";

// Mover archivo
if (!move_uploaded_file($_FILES['video']['tmp_name'], $nombreFinal)) {
    echo json_encode(['success' => false, 'message' => 'Error al guardar el archivo en el servidor.']);
    exit;
}

// Insertar en la base de datos
$sql = "INSERT INTO tb_video (video, ruta, activo, condicion) VALUES (?, ?, 1, 1)";
$stmt = mysqli_prepare($conex, $sql);
if (!$stmt) {
    echo json_encode(['success' => false, 'message' => 'Error al preparar consulta.']);
    exit;
}

mysqli_stmt_bind_param($stmt, 'ss', $descripcion, $nombreFinal);
if (mysqli_stmt_execute($stmt)) {
    echo json_encode(['success' => true, 'message' => 'Video agregado correctamente.']);
} else {
    echo json_encode(['success' => false, 'message' => 'Error al guardar en la base de datos.']);
}

mysqli_stmt_close($stmt);
?>
