<?php
// Iniciar sesión solo si no está activa
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

$currentPage = basename($_SERVER['PHP_SELF']);

$configPages = ['usuarios.php', 'zonas.php', 'cantones.php', 'vehiculos.php', 'table.php', 'video.php', 'marcas.php'];
$reportPages = ['ventas_reporte.php', 'ganadores.php', 'caducados_r.php', 'reporte_fecha.php', 'reporte_u_p.php', 'reporte_u_p3c.php', 'reporte_u_p4c.php'];

$isConfigActive = in_array($currentPage, $configPages);
$isReportActive = in_array($currentPage, $reportPages);
?>

<style>
/* Sidebar base */
.sidebar {
    width: 250px;
    background-color: #2c3e50;
    color: white;
    min-height: 100vh;
    padding-top: 60px;
    position: fixed;
    top: 0;
    left: 0;
    overflow-y: auto;
    z-index: 1000;
    transition: all 0.3s ease;
}

/* Oculta sidebar en móviles */
@media (max-width: 768px) {
    .sidebar {
        transform: translateX(-100%);
    }
    .sidebar.show {
        transform: translateX(0);
    }
}

/* Enlace del menú */
.sidebar a {
    display: block;
    color: white;
    padding: 12px 20px;
    text-decoration: none;
    transition: background 0.3s ease;
}

.sidebar a:hover,
.sidebar a.active {
    background-color: #34495e;
}

.sidebar i {
    margin-right: 10px;
}

.sidebar .submenu {
    display: none;
    background-color: #34495e;
}

.sidebar .submenu a {
    padding-left: 40px;
    font-size: 0.95em;
    background-color: #3d566e;
}

.submenu-toggle.active + .submenu {
    display: block;
}
</style>

<div class="sidebar" id="sidebar">
    <a href="index.php" class="<?= $currentPage == 'index.php' ? 'active' : '' ?>"><i class="fa fa-home"></i> <span>Inicio</span></a>

    <a href="#" class="submenu-toggle <?= $isConfigActive ? 'active' : '' ?>">
        <i class="fas fa-cogs"></i> <span>Administración</span>
    </a>
    <ul class="submenu" style="display: <?= $isConfigActive ? 'block' : 'none' ?>;">
        <!--li><a href="usuarios.php" class="<?= $currentPage == 'usuarios.php' ? 'active' : '' ?>"><i class="fas fa-users"></i> Usuarios</a></li-->
        <li><a href="zonas.php" class="<?= $currentPage == 'zonas.php' ? 'active' : '' ?>"><i class="fas fa-sitemap"></i> Zonas</a></li>
        <li><a href="cantones.php" class="<?= $currentPage == 'cantones.php' ? 'active' : '' ?>"><i class="fas fa-sort-amount-down-alt"></i> Cantones</a></li>
        <li><a href="vehiculos.php" class="<?= $currentPage == 'vehiculos.php' ? 'active' : '' ?>"><i class="fas fa-car"></i> Vehículos</a></li>
        <li><a href="table.php" class="<?= $currentPage == 'table.php' ? 'active' : '' ?>"><i class="fas fa-television"></i> Table</a></li>
        <li><a href="video.php" class="<?= $currentPage == 'video.php' ? 'active' : '' ?>"><i class="fa fa-video-camera"></i> Video</a></li>
        <li><a href="marcas.php" class="<?= $currentPage == 'marcas.php' ? 'active' : '' ?>"><i class="fa fa-puzzle-piece"></i> Marcas</a></li>
    </ul>
	<a href="publicidad.php" class="<?= $currentPage == 'publicidad.php' ? 'active' : '' ?>"><i class="fa fa-history"></i> <span>Publicidad</span></a>
    <a href="#" class="submenu-toggle <?= $isReportActive ? 'active' : '' ?>">
        <i class="fas fa-hdd"></i> <span>Reportes</span>
    </a>
    <ul class="submenu" style="display: <?= $isReportActive ? 'block' : 'none' ?>;">
        <li><a href="ventas_reporte.php" class="<?= $currentPage == 'ventas_reporte.php' ? 'active' : '' ?>"><i class="fas fa-users"></i> Ventas por día</a></li>
        <li><a href="ganadores.php" class="<?= $currentPage == 'ganadores.php' ? 'active' : '' ?>"><i class="fas fa-sitemap"></i> Ganadores por día</a></li>
        <li><a href="caducados_r.php" class="<?= $currentPage == 'caducados_r.php' ? 'active' : '' ?>"><i class="fas fa-hourglass"></i> Ganadores caducados</a></li>
        <li><a href="reporte_fecha.php" class="<?= $currentPage == 'reporte_fecha.php' ? 'active' : '' ?>"><i class="fas fa-calendar-alt"></i> Reporte por fecha</a></li>
        <li><a href="reporte_u_p.php" class="<?= $currentPage == 'reporte_u_p.php' ? 'active' : '' ?>"><i class="fas fa-wrench"></i> Utilidad - Pérdida 2 cifras</a></li>
        <li><a href="reporte_u_p3c.php" class="<?= $currentPage == 'reporte_u_p3c.php' ? 'active' : '' ?>"><i class="fas fa-wrench"></i> Utilidad - Pérdida 3 cifras</a></li>
        <li><a href="reporte_u_p4c.php" class="<?= $currentPage == 'reporte_u_p4c.php' ? 'active' : '' ?>"><i class="fas fa-wrench"></i> Utilidad - Pérdida 4 cifras</a></li>
    </ul>

    <a href="historial.php" class="<?= $currentPage == 'historial.php' ? 'active' : '' ?>"><i class="fa fa-history"></i> <span>Historial</span></a>
</div>

<script>
// Submenús toggle
document.addEventListener("DOMContentLoaded", function () {
    const submenuToggles = document.querySelectorAll(".submenu-toggle");
    submenuToggles.forEach(toggle => {
        toggle.addEventListener("click", function (event) {
            event.preventDefault();
            const submenu = this.nextElementSibling;
            const isOpen = submenu.classList.contains("active");
            closeAllSubmenus();
            if (!isOpen) {
                submenu.classList.add("active");
                submenu.style.display = "block";
                this.classList.add("active");
            }
        });
    });

    function closeAllSubmenus() {
        document.querySelectorAll(".submenu").forEach(submenu => {
            submenu.classList.remove("active");
            submenu.style.display = "none";
        });
        document.querySelectorAll(".submenu-toggle").forEach(toggle => {
            toggle.classList.remove("active");
        });
    }
});
</script>
